@@ -1,6 +1,7 @@
 import os
 import sys
 import threading
+import types
 import warnings
 from typing import Optional
 
@@ -99,6 +100,20 @@ class DatabaseContext:
         return self.database.__exit__(exc_type, exc_val, exc_tb)
 
 
+class SessionWrapper(Session):
+    _closed = False
+
+    def __getattribute__(self, item):
+        attr = super().__getattribute__(item)
+        if isinstance(attr, types.MethodType) and self._closed:
+            raise AssertionError("Session is already closed")
+        return attr
+
+    def close(self):
+        super().close()
+        self._closed = True
+
+
 class Database:
     active_session: Optional[Session]
 
@@ -106,7 +121,7 @@ class Database:
         self.db_folder = database_folder
         self.name = name
         self._engine = get_database(database_folder, name, alembic_path)
-        self._session = sessionmaker(self._engine)
+        self._session = sessionmaker(bind=self._engine, class_=SessionWrapper)
         self.active_session = None
         self.lock = threading.RLock()
 
@@ -114,9 +129,8 @@ class Database:
         return bool(self._session)
 
     def shutdown(self):
-        assert self.is_open(), (
-            "database is already closed, you called shutdown twice somewhere"
-        )
+        assert self.is_open(), "database is already closed, you called shutdown twice somewhere"
+
         with self.lock:
             self._session = None
             global active_databases
@@ -126,13 +140,13 @@ class Database:
         return DatabaseContext(self, expire_on_commit=expire_on_commit)
 
     def __enter__(self, expire_on_commit=True) -> Session:
-        assert self._session, "Database is already closed"
+        assert self._session, "Session is already closed"
         self.lock.acquire()
         self.active_session = self._session(expire_on_commit=expire_on_commit)
         return self.active_session
 
     def flush(self, objects=None):
-        assert self._session
+        assert self._session and self.active_session, "Session is already closed"
         self.active_session.flush(objects)
 
     def __exit__(self, exc_type, exc_val, exc_tb):
