@@ -1,6 +1,5 @@
 import logging
 import os
-import shutil
 import socket
 import warnings
 from types import SimpleNamespace
@@ -10,13 +9,12 @@ from unittest import TestCase
 from pydantic import ValidationError
 
 from openmodule import config
-from openmodule.config import validate_config_module, LazySettings, override_settings, _override_settings, settings, \
+from openmodule.config import validate_config_module, LazySettings, override_settings, settings, \
     override_context
 from openmodule.models.base import OpenModuleModel
 from openmodule_test.files import temp_file
-from openmodule_test.utils import DeveloperError
 from openmodule_test.zeromq import ZMQTestMixin
-from tests.resources import test_config
+from tests.resources.configs import test_config
 
 
 class EnvTestCase(TestCase):
@@ -263,17 +261,17 @@ class LazyConfigTest(TestCase):
 
     def test_double_configure(self):
         settings.configure(test_config)
-        with self.assertRaises(DeveloperError) as e:
+        with self.assertRaises(AssertionError) as e:
             settings.configure(test_config)
         self.assertIn("Settings are already configured", str(e.exception))
 
         second_setting = LazySettings()
-        with self.assertRaises(DeveloperError) as e:
+        with self.assertRaises(AssertionError) as e:
             second_setting.configure(test_config)
         self.assertIn("Do not use multiple settings", str(e.exception))
 
     def test_environment(self):
-        os.environ["SETTINGS_MODULE"] = "../tests/resources/test_config_1.py"
+        os.environ["SETTINGS_MODULE"] = "tests.resources.configs.test_config_1"
         self.assertEqual("THIS_IS_MY_NAME_TOO", settings.NAME)
         self.assertEqual("bsdf", settings.TEST)
         del os.environ["SETTINGS_MODULE"]
@@ -299,6 +297,7 @@ class LazyConfigTest(TestCase):
             self.assertEqual("abc", settings.NAME)
         self.assertEqual("THIS_IS_MY_NAME", settings.NAME)
 
+
 @override_settings(BROKER_SUB=f"inproc://test-sub-aaaaaaaaaa")
 class ZmqConfigTest(ZMQTestMixin):
 
