@@ -99,3 +99,6 @@ class ZMQMessageTestCase(TestCase):
 
         errors = e.exception.errors()
         self.assertEqual(errors[0]["loc"], ("gateway", "direction"))
+
+    def test_unicode_decode_with_old_omutils(self):
+        pass
